@@ -6,9 +6,9 @@ Type annotations for secretsmanager service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_secretsmanager.literals import FilterNameStringType
+    from mypy_boto3_secretsmanager.literals import FilterNameStringTypeType
 
-    data: FilterNameStringType = "all"
+    data: FilterNameStringTypeType = "all"
     ```
 """
 import sys
@@ -19,12 +19,17 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("FilterNameStringType", "ListSecretsPaginatorName", "SortOrderType", "StatusType")
+__all__ = (
+    "FilterNameStringTypeType",
+    "ListSecretsPaginatorName",
+    "SortOrderTypeType",
+    "StatusTypeType",
+)
 
 
-FilterNameStringType = Literal[
+FilterNameStringTypeType = Literal[
     "all", "description", "name", "primary-region", "tag-key", "tag-value"
 ]
 ListSecretsPaginatorName = Literal["list_secrets"]
-SortOrderType = Literal["asc", "desc"]
-StatusType = Literal["Failed", "InProgress", "InSync"]
+SortOrderTypeType = Literal["asc", "desc"]
+StatusTypeType = Literal["Failed", "InProgress", "InSync"]
